@@ -3,7 +3,7 @@
  
 Dancer::Plugin::BeforeRoute - A before hook for a specify route or routes
   
-=head1 SYNOPSIS
+=head1 USAGE
 
  use Dancer::Plugin::BeforeRoute;
 
@@ -11,6 +11,10 @@ Dancer::Plugin::BeforeRoute - A before hook for a specify route or routes
      var before_run => "homepage";
  };
 
+ before_route ["get", "post"] => "/", sub {
+     var before_run => "homepage";
+ };
+
  get "/" => sub {
      ## Return "homepage"
      return var "before_run";
@@ -83,9 +87,7 @@ under the same terms as Perl itself.
 =cut
 
 package Dancer::Plugin::BeforeRoute;
-{
-  $Dancer::Plugin::BeforeRoute::VERSION = '0.6';
-}
+$Dancer::Plugin::BeforeRoute::VERSION = '0.61';
 use Carp "confess";
 use Dancer ":syntax";
 use Dancer::Plugin;
@@ -147,7 +149,7 @@ sub _args {
 
 sub _is_the_right_method {
     my $method  = shift;
-    my @methods = shift;
+    my @methods = @_;
     return ( grep { /^\Q$method\E$/i } @methods ) ? 1 : 0;
 }
 
